@@ -18,21 +18,19 @@
 import os
 import rpm
 import types
-import re
 
 from yum.packages import YumLocalPackage
 from yum.Errors import *
 from yum import misc
-from yum.sqlutils import executeSQL
-from rpmUtils.transaction import initReadOnlyTransaction
-from rpmUtils.miscutils import flagToString, stringToVersion
 import utils
 import tempfile
 
 class CreateRepoPackage(YumLocalPackage):
-    def __init__(self, ts, package):
+    def __init__(self, ts, package, sumtype=None):
         YumLocalPackage.__init__(self, ts, package)
-        
+        if sumtype:
+            self.checksum_type = sumtype
+
     def _do_checksum(self):
         """return a checksum for a package:
            - check if the checksum cache is enabled
@@ -60,7 +58,7 @@ class CreateRepoPackage(YumLocalPackage):
         if type(self.hdr[rpm.RPMTAG_HDRID]) is not types.NoneType:
             t.append("".join(self.hdr[rpm.RPMTAG_HDRID]))
 
-        kcsum = misc.Checksums()
+        kcsum = misc.Checksums(checksums=[self.checksum_type])
         kcsum.update("".join(t))
         key = kcsum.hexdigest()
                                                 
